@@ -21,11 +21,13 @@
 #define XFCE4_SENSORS_HDDTEMP_H
 
 #include <glib.h>
+#include <string>
+#include <vector>
+#include "xfce4++/util.h"
 
+#include "sensors-interface-plugin.h"
 #include "types.h"
 
-G_BEGIN_DECLS
-
 #define HDDTEMP_DISK_SLEEPING       ZERO_KELVIN /* must be larger than the remaining ones */
 #define NO_VALID_HDDTEMP_PROGRAM    ZERO_KELVIN-1 /* the calls/communication to hddtemp don't work */
 #define NO_VALID_TEMPERATURE_VALUE  ZERO_KELVIN-2 /* the value for a single disk is invalid */
@@ -33,20 +35,16 @@ G_BEGIN_DECLS
 
 /**
  * Initialize hddtemp by finding disks to monitor
- * @param chips: Pointer to array of chips
  * @param suppress_message: returns whether messages shall be suppressed
  * @return Number of initialized chips
  */
-int initialize_hddtemp (GPtrArray *chips, gboolean *suppress_message);
+int initialize_hddtemp (std::vector<Ptr<t_chip>> &chips, bool *suppress_message);
 
 
 /**
  * Refreshs a hddtemp chip's feature in sense of raw and formatted value
- *
- * @param chip_feature: Pointer to feature
- * @param sensors: Pointer to t_sensors or NULL
  */
-void refresh_hddtemp (gpointer chip_feature, gpointer sensors);
+void refresh_hddtemp (const Ptr<t_chipfeature> &feature, const Ptr<t_sensors> &sensors);
 
 
 /**
@@ -55,8 +53,6 @@ void refresh_hddtemp (gpointer chip_feature, gpointer sensors);
  * @param suppress_message: returns whether messages shall be suppressed
  * @return Temperature of disk
  */
-double get_hddtemp_value (char *disk, gboolean *suppress_message);
-
-G_END_DECLS
+double get_hddtemp_value (const std::string &disk, bool *suppress_message);
 
 #endif /* XFCE4_SENSORS_HDDTEMP_H */
