@@ -27,25 +27,20 @@
 #include <glib.h>
 #include <gtk/gtk.h>
 #include <libxfce4panel/libxfce4panel.h>
-#include <stdbool.h>
+#include <map>
+#include <string>
+#include <vector>
 
 /* Package includes */
 #include "sensors-interface-types.h"
 #include "types.h"
 
-G_BEGIN_DECLS
-
-#define MAX_NUM_CHIPS 10
-#define MAX_NUM_FEATURES 256
-
-
 /**
  * Sensors module
  */
-typedef struct {
-
+struct t_sensors {
     /** pointer for Xfce Panel */
-    XfcePanelPlugin *plugin;
+    XfcePanelPlugin *const plugin;
 
     /** eventbox to catch events */
     GtkWidget *eventbox;
@@ -57,119 +52,113 @@ typedef struct {
     GtkWidget *panel_label_text;
 
     /** text UI style */
-	struct {
-		GtkWidget *draw_area;
-		bool reset_size:1;
-	} text;
+    struct {
+        GtkWidget *draw_area;
+        bool reset_size = true;
+    } text;
 
     /** update the tooltip */
-    gint timeout_id;
+    guint timeout_id;
 
     /** font size for display in panel */
-    gchar *str_fontsize;
-    gint val_fontsize;
+    std::string str_fontsize = "medium";
+    gint val_fontsize = 2;
 
     /** temperature scale for display in panel */
-    t_tempscale scale;
+    t_tempscale scale = CELSIUS;
 
     /** panel size to compute number of cols/columns */
     gint panel_size;
 
     /** Requested/allowed number of lines in text mode */
-    gint lines_size;
+    gint lines_size = 3;
 
     /** panel orientation */
-    XfcePanelPluginMode plugin_mode;
+    XfcePanelPluginMode plugin_mode = XFCE_PANEL_PLUGIN_MODE_HORIZONTAL;
 
     /** automatic bar colors */
-    bool automatic_bar_colors:1;
+    bool automatic_bar_colors = false;
 
-    /** The panel plugins can cover all rows/columns of the panel, but default is to not do so */
-    bool cover_panel_rows:1;
+    /** The panel plugins can cover all rows/columns of the panel, but default is not to do so */
+    bool cover_panel_rows = false;
 
     /** if the bars have been initialized */
-    bool bars_created:1;
+    bool bars_created = false;
 
     /** if the tachos have been initialized */
-    bool tachos_created:1;
+    bool tachos_created = false;
 
     /** show title in panel */
-    bool show_title:1;
+    bool show_title = false;
 
     /** show labels in panel (GUI mode only) */
-    bool show_labels:1;
+    bool show_labels = true;
 
     /** show units in textual view */
-    bool show_units:1;
+    bool show_units = true;
 
     /** show small spacings only in textual view */
-    bool show_smallspacings:1;
+    bool show_smallspacings = false;
 
     /**
      * suppress tooltip from overlapping widget and thereby crashing the plugin
      * or modifying the background
      */
-    bool suppresstooltip:1;
+    bool suppresstooltip = false;
 
     /**
      * double-click improvement as suggested on xfce4-goodies@berlios.de.
      * whether to execute command on double click
      */
-    bool exec_command:1;
+    bool exec_command = true;
 
     /** suppress Hddtemp failure messages and any other messages */
-    gboolean suppressmessage;
+    bool suppressmessage = false;
 
     /** use the progress-bar UI */
-    e_displaystyles display_values_type;
+    e_displaystyles display_values_type = DISPLAY_TEXT;
 
-    /** sensor update time */
-    gint sensors_refresh_time;
+    /** sensor update time, in seconds */
+    gint sensors_refresh_time = 60;
 
     /* sensor relevant stuff */
-    /**
-     * no problem if less than 11 sensors, else will have to enlarge the
-     * following arrays. NYI!!
-     */
-    gint num_sensorchips;
 
     /** contains the progress bar panels */
-    /* FIXME:    Might be replaced by GPtrArray as well */
-    t_labelledlevelbar *panels[MAX_NUM_CHIPS][MAX_NUM_FEATURES];
-    /*    GArray *panels_array; */
+    std::map<Ptr<t_chipfeature>, Ptr<t_labelledlevelbar>> panels;
 
     /** CSS provider for main dialog */
     GtkCssProvider *css_provider;
 
     /** contains the tacho panels */
-    /* FIXME:    Might be replaced by GPtrArray as well */
-    GtkWidget *tachos[MAX_NUM_CHIPS][MAX_NUM_FEATURES];
+    std::map<Ptr<t_chipfeature>, GtkWidget*> tachos;
 
     /** sensor types to display values in appropriate format */
-    GPtrArray *chips;
+    std::vector<Ptr<t_chip>> chips;
 
-    /** command to excute */
-    gchar *command_name;
+    /** command to execute */
+    std::string command_name = "xfce4-sensors";
 
     /** callback_id for doubleclicks */
-    gint doubleclick_id;
+    gint doubleclick_id = 0;
 
-    /** file name of config file for plugin */
-    gchar *plugin_config_file;
+    /** filepath of config file for plugin, or an empty string */
+    std::string plugin_config_file;
 
     /** preferred dialog width */
-    gint preferred_width;
+    gint preferred_width = 675;
 
     /** preferred dialog height */
-    gint preferred_height;
+    gint preferred_height = 400;
 
     /** color value for the tachometers, useful for dark themes where lower brightness is required */
-    gfloat val_tachos_color;
+    gfloat tachos_color;
 
     /** desired alpha value for the tachometers */
-    gfloat val_tachos_alpha;
-}
-t_sensors;
+    gfloat tachos_alpha;
+
+    t_sensors(XfcePanelPlugin *plugin);
+    ~t_sensors();
+};
 
 
 /* Regularly included functions in library */
@@ -180,15 +169,6 @@ t_sensors;
  * @param plugin_config_filename
  * @return pointer to newly allocated sensors object
  */
-t_sensors* sensors_new (XfcePanelPlugin *plugin, gchar *plugin_config_filename);
-
-/**
- * Initialize sensors structure with default values
- * @param sensors: pointer to sensors plugin data
- * @param plugin: Pointer to panel plugin data
- */
-void sensors_init_default_values (t_sensors *sensors, XfcePanelPlugin *plugin);
-
-G_END_DECLS
+Ptr0<t_sensors> sensors_new (XfcePanelPlugin *plugin, const char *plugin_config_filename_orNull);
 
 #endif /* XFCE4_SENSORS_INTERFACE_PLUGIN_H */
