@@ -22,8 +22,7 @@
 
 #include <cairo.h>
 #include <gtk/gtk.h>
-
-G_BEGIN_DECLS
+#include <string>
 
 G_DECLARE_FINAL_TYPE (GtkSensorsTacho, gtk_sensorstacho, GTK, SENSORSTACHO, GtkDrawingArea)
 
@@ -32,14 +31,14 @@ typedef struct _GtkSensorsTacho GtkSensorsTacho;
 /**
  * Enumeration of possible style for sensors tacho.
  */
-typedef enum _SensorsTachoStyle {
+enum SensorsTachoStyle {
     /** temperatures, ranging from green over yellow to red */
     style_MinGYR = 0,
     /** voltage and power, from yellow over green to blue */
     style_MediumYGB = 1,
     /** fill level, mostly used for energy from red over yellow to green */
     style_MaxRYG = 2
-} SensorsTachoStyle;
+};
 
 /**
  * pseudo widget for drawing a tacho
@@ -49,11 +48,13 @@ struct _GtkSensorsTacho {
     GtkDrawingArea parent;
 
     /** value to display */
-    gdouble sel;
+    gdouble value;
 
     /** pointer to string of sensor name to display */
     gchar *text;
 
+    gint text_width, text_height;
+
     /** pointer to color as hexadecimal rgb value in a string */
     gchar *color_orNull;
 
@@ -126,8 +127,8 @@ void gtk_sensorstacho_set_size(GtkSensorsTacho *tacho, guint size);
  * tacho elements.
  * TODO: Introduce getter/setter functions
  */
-extern gchar *font;
-
+extern std::string font;
+extern const char *const default_font;
 
 #define MAX_HUE 0.8
 #define ALPHA_CHANNEL_VALUE 0.8
@@ -146,6 +147,4 @@ extern gfloat val_colorvalue;
  */
 extern gfloat val_alpha;
 
-G_END_DECLS
-
 #endif /* __TACHO_H */
