@@ -1,6 +1,7 @@
-/* File: actions.h
+/* actions.h
+ * Part of xfce4-sensors-plugin
  *
- * Copyright 2008-2017 Fabian Nowak (timystery@arcor.de)
+ * Copyright (c) 2008-2017 Fabian Nowak <timystery@arcor.de>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -26,17 +27,14 @@
 #include <sensors-interface-common.h>
 #include <tacho.h>
 
-G_BEGIN_DECLS
-
 /**
  * Shall refresh the entire view of the application
- * @param dialog: pointer to sensors dialog structure
- * @return TRUE: argument is valid
  */
-void refresh_view (t_sensors_dialog *dialog);
+void refresh_view (const Ptr<t_sensors_dialog> &dialog);
 
-gboolean refresh_view_cb (gpointer user_data);
-
-G_END_DECLS
+/**
+ * Add missing tachos, remove excessive tachos, and re-arrange tachos
+ */
+void refresh_tacho_view (const Ptr<t_sensors_dialog> &dialog);
 
 #endif /* ACTIONS_H */
