@@ -1,6 +1,7 @@
-/* File: interface.h
+/* interface.h
+ * Part of xfce4-sensors-plugin
  *
- * Copyright 2008-2017 Fabian Nowak (timystery@arcor.de)
+ * Copyright (c) 2008-2017 Fabian Nowak <timystery@arcor.de>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -17,19 +18,20 @@
  * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  */
 
+#ifndef __INTERFACE_H
+#define __INTERFACE_H
+
 #include <glib.h>
 #include <gtk/gtk.h>
 
 /* Package includes */
 #include <sensors-interface-common.h>
 
-G_BEGIN_DECLS
-
 /**
  * Populate the application's main window
  * @param dialog: pointer to already filled sensors dialog structure
  * @return newly allocated GtkWidget of main window
  */
-GtkWidget* create_main_window (t_sensors_dialog *dialog);
+GtkWidget* create_main_window (const Ptr<t_sensors_dialog> &dialog);
 
-G_END_DECLS
+#endif /* __INTERFACE_H */
